@@ -5,28 +5,18 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef DocumentModel_H
-#define DocumentModel_H
+#ifndef DOCUMENT_MODEL_H
+#define DOCUMENT_MODEL_H
 
 #include <memory>
 
 #include <QAbstractListModel>
 #include <QString>
 #include <QUrl>
-#include <QSize>
 
 #include "SkanpageUtils.h"
 
-struct PreviewPageProperties {
-    double aspectRatio;
-    int previewWidth;
-    int previewHeight;
-    int pageID;
-    bool isSaved;
-};
-
-class DocumentSaver;
-class DocumentPrinter;
+class DocumentModelPrivate;
 
 class DocumentModel : public QAbstractListModel
 {
@@ -46,6 +36,12 @@ public:
         PreviewHeightRole,
         IsSavedRole};
 
+    enum RotateOption { Rotate90positive,
+        Rotate90negative,
+        Flip180};
+
+    Q_ENUM(RotateOption);
+
     explicit DocumentModel(QObject *parent = nullptr);
     ~DocumentModel();
 
@@ -65,9 +61,11 @@ public:
 
     Q_INVOKABLE void removeImage(int row);
 
-    Q_INVOKABLE void rotateImage(int row, bool positiveDirection);
+    Q_INVOKABLE void rotateImage(int row, RotateOption rotate = RotateOption::Rotate90positive);
 
-    Q_INVOKABLE void save(const QUrl &fileUrl);
+    Q_INVOKABLE void save(const QUrl &fileUrl, QList<int> pageNumbers = {});
+
+    Q_INVOKABLE void createSharingFile(const QString &suffix, QList<int> pageNumbers = {});
 
     Q_INVOKABLE void print();
 
@@ -81,22 +79,21 @@ Q_SIGNALS:
     void activePageChanged();
     void countChanged();
     void newPageAdded();
-    void showUserMessage(SkanpageUtils::MessageLevel level, const QString &text);
+    void saveDocument(const QUrl &fileUrl, const SkanpageUtils::DocumentPages &document, const SkanpageUtils::FileType type = SkanpageUtils::EntireDocument);
+    void printDocument(const SkanpageUtils::DocumentPages &document);
+    void saveNewPageTemporary(const int pageID, const QImage &image);
+    void sharingDocumentsCreated(const QVariantList &fileUrls);
 
-private Q_SLOTS:
-    void updateFileInformation(const QString &fileName, const SkanpageUtils::DocumentPages &document);
-
-private:
+public Q_SLOTS:
+    void updateFileInformation(const QList<QUrl> &fileUrls, const SkanpageUtils::DocumentPages &document);
+    void updateSharingFileInformation(const QList<QUrl> &fileUrls);
     void updatePageInModel(const int pageID, const SkanpageUtils::PageProperties &page);
 
-    SkanpageUtils::DocumentPages m_pages;
-    QList<PreviewPageProperties> m_details;
-    QString m_name;
-    bool m_changed = false;
-    int m_activePageIndex = -1;
-    int m_idCounter = 0;
-    std::unique_ptr<DocumentSaver> m_documentSaver;
-    std::unique_ptr<DocumentPrinter> m_documentPrinter;
+private:
+
+    SkanpageUtils::DocumentPages selectPages(QList<int> pageNumbers);
+
+    std::unique_ptr<DocumentModelPrivate> d;
 };
 
-#endif
+#endif // DOCUMENT_MODEL_H
