@@ -5,8 +5,8 @@
  */
 
 //KDE includes
-
-#include <klocalizedstring.h>
+#include <KConfigGroup>
+#include <KSharedConfig>
 
 #include "OptionsModel.h"
 #include "skanpage_debug.h"
@@ -15,18 +15,39 @@ class OptionsModelPrivate
 {
 public:
     QList<KSaneIface::KSaneOption *> mOptionsList;
-    QVariantList mCurrentValueList;
-    bool mIsModified = false;
+    QList<bool> mQuickAccessList;
+    QSet<QString> mQuickAccessOptions;
+    bool mQuickAccessListChanged = false;
 };
 
 OptionsModel::OptionsModel(QObject *parent)
     : QAbstractListModel(parent)
-    , d(std::unique_ptr<OptionsModelPrivate>(new OptionsModelPrivate()))
+    , d(std::make_unique<OptionsModelPrivate>())
 {
+    //if there are no defined quick access options yet, insert default ones
+    KConfigGroup quickOptions(KSharedConfig::openConfig(), QStringLiteral("quickAccessOptions"));
+    if (!quickOptions.exists()) {
+        d->mQuickAccessOptions.insert(QStringLiteral("KSane::PageSize"));
+        d->mQuickAccessOptions.insert(QStringLiteral("resolution"));
+        d->mQuickAccessOptions.insert(QStringLiteral("source"));
+        d->mQuickAccessOptions.insert(QStringLiteral("mode"));
+    } else {
+        const QStringList keys = quickOptions.keyList();
+        d->mQuickAccessOptions = QSet(keys.begin(), keys.end());
+    }
 }
 
 OptionsModel::~OptionsModel()
-{
+{    
+    if (d->mQuickAccessListChanged) {
+        KConfigGroup quickOptions(KSharedConfig::openConfig(), QStringLiteral("quickAccessOptions"));
+        quickOptions.deleteGroup();
+        for (int i = 0; i < d->mOptionsList.size(); i++) {
+            if (d->mQuickAccessList.at(i)) {
+                quickOptions.writeEntry(d->mOptionsList.at(i)->name(), true);
+            }
+        }
+    }
 }
 
 QHash<int, QByteArray> OptionsModel::roleNames() const
@@ -42,7 +63,8 @@ QHash<int, QByteArray> OptionsModel::roleNames() const
     roles[ValueListRole] = "valueList";
     roles[UnitRole] = "unit";
     roles[TypeRole] = "type";
-    roles[VisibleRole] = "visible";
+    roles[StateRole] = "state";
+    roles[QuickAccessRole] = "quickAccess";
     return roles;
 }
 
@@ -51,11 +73,6 @@ int OptionsModel::rowCount(const QModelIndex &) const
     return d->mOptionsList.count();
 }
 
-bool OptionsModel::isModified() const
-{
-    return d->mIsModified;
-}
-
 QVariant OptionsModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
@@ -77,7 +94,7 @@ QVariant OptionsModel::data(const QModelIndex &index, int role) const
         return d->mOptionsList.at(index.row())->description();
         break;
     case ValueRole:
-        return d->mCurrentValueList.at(index.row());
+        return d->mOptionsList.at(index.row())->value();
         break;
     case MaximumValueRole:
         return d->mOptionsList.at(index.row())->maximumValue();
@@ -97,8 +114,12 @@ QVariant OptionsModel::data(const QModelIndex &index, int role) const
     case TypeRole:
         return d->mOptionsList.at(index.row())->type();
         break;
-    case VisibleRole:
-        return d->mOptionsList.at(index.row())->state() == KSaneIface::KSaneOption::KSaneOptionState::StateActive;
+    case StateRole:
+        return d->mOptionsList.at(index.row())->state();
+        break;
+    case QuickAccessRole:
+        return d->mQuickAccessList.at(index.row());
+        break;
     default:
         break;
     }
@@ -107,15 +128,19 @@ QVariant OptionsModel::data(const QModelIndex &index, int role) const
 
 bool OptionsModel::setData(const QModelIndex &index, const QVariant &value, int role)
 {
-    if (role != ValueRole || index.row() < 0 || index.row() >= d->mOptionsList.size()) {
+    if ((role != ValueRole && role != QuickAccessRole) || index.row() < 0 || index.row() >= d->mOptionsList.size()) {
         return false;
     }
-    if (d->mOptionsList.at(index.row())->type() == KSaneIface::KSaneOption::TypeAction) {
+    if (role == ValueRole) {
         d->mOptionsList.at(index.row())->setValue(value);
-    } else {
-        d->mCurrentValueList[index.row()] = value;
-        d->mIsModified = true;
-        Q_EMIT isModifiedChanged();
+        qCDebug(SKANPAGE_LOG()) << "OptionsModel: Writing to option" << d->mOptionsList.at(index.row())->name() << value;
+        Q_EMIT dataChanged(index, index, {ValueRole});
+        return true;
+    }
+    if (role == QuickAccessRole) {
+        d->mQuickAccessList[index.row()] = value.toBool();
+        d->mQuickAccessListChanged = true;
+        Q_EMIT dataChanged(index, index, {QuickAccessRole});
     }
     return true;
 }
@@ -124,60 +149,24 @@ void OptionsModel::setOptionsList(const QList<KSaneIface::KSaneOption *> options
 {
     beginResetModel();
     d->mOptionsList = optionsList;
-    d->mCurrentValueList.clear();
-    d->mCurrentValueList.reserve(optionsList.size());
+    d->mQuickAccessList.clear();
+    d->mQuickAccessList.reserve(optionsList.size());
     for (int i = 0; i < d->mOptionsList.size(); i++) {
         KSaneIface::KSaneOption *option = d->mOptionsList.at(i);
         qCDebug(SKANPAGE_LOG()) << "OptionsModel: Importing option " << option->name() << ", type" << option->type() << ", state" << option->state();
-        d->mCurrentValueList.append(option->value());
-        connect(option, &KSaneIface::KSaneOption::optionReloaded, this, [=]() { Q_EMIT dataChanged(index(i, 0), index(i, 0), {VisibleRole}); });
-        connect(option, &KSaneIface::KSaneOption::valueChanged, this, [=]() { d->mCurrentValueList[i] = option->value(); Q_EMIT dataChanged(index(i, 0), index(i, 0), {ValueRole}); });
+        connect(option, &KSaneIface::KSaneOption::optionReloaded, this, [=]() { Q_EMIT dataChanged(index(i, 0), index(i, 0), {StateRole}); });
+        connect(option, &KSaneIface::KSaneOption::valueChanged, this, [=]() { Q_EMIT dataChanged(index(i, 0), index(i, 0), {ValueRole}); });
+        d->mQuickAccessList.insert(i, d->mQuickAccessOptions.contains(option->name()));
     }
     endResetModel();
     Q_EMIT rowCountChanged();
 }
 
-void OptionsModel::resetOptionsValues()
-{
-    if (d->mIsModified == false) {
-        return;
-    }
-    for (int i = 0; i < d->mOptionsList.size(); i++) {
-        if (d->mCurrentValueList[i] != d->mOptionsList.at(i)->value()) {;
-            d->mCurrentValueList[i] = d->mOptionsList.at(i)->value();
-            Q_EMIT dataChanged(index(i, 0), index(i, 0), {ValueRole});
-        }
-    }
-    d->mIsModified = false;
-    Q_EMIT isModifiedChanged();
-    qCDebug(SKANPAGE_LOG()) << "OptionsModel reset";
-}
-
-void OptionsModel::saveOptionsValues()
-{
-    if (d->mIsModified == false) {
-        return;
-    }
-    for (int i = 0; i < d->mOptionsList.size(); i++) {
-        if (d->mOptionsList.at(i)->state() == KSaneIface::KSaneOption::KSaneOptionState::StateActive &&
-            d->mOptionsList.at(i)->type() != KSaneIface::KSaneOption::TypeAction &&
-            d->mOptionsList.at(i)->value() != d->mCurrentValueList.at(i)) {
-
-            d->mOptionsList.at(i)->setValue(d->mCurrentValueList.at(i));
-            qCDebug(SKANPAGE_LOG()) << "OptionsModel: Writing to option" << d->mOptionsList.at(i)->name() << d->mCurrentValueList.at(i);
-        }
-    }
-    d->mIsModified = false;
-    Q_EMIT isModifiedChanged();
-}
-
 void OptionsModel::clearOptions()
 {
     beginResetModel();
     d->mOptionsList.clear();
-    d->mCurrentValueList.clear();
-    d->mIsModified = false;
+    d->mQuickAccessList.clear();
     endResetModel();
     Q_EMIT rowCountChanged();
-    Q_EMIT isModifiedChanged();
 }
